API Reference
-------------

.. currentmodule:: wcosmo

.. autosummary::
   :toctree: .
   :template: custom-module-template.rst
   :caption: API
   :recursive:

   astropy
   taylor
   utils
   wcosmo
